#define GNOME_CANVAS_MAJOR_VERSION (2)
#define GNOME_CANVAS_MINOR_VERSION (10)
#define GNOME_CANVAS_MICRO_VERSION (0)
#define GNOME_CANVAS_CHECK_VERSION(major,minor,micro) \
	(GNOME_CANVAS_MAJOR_VERSION > (major) || \
	 (GNOME_CANVAS_MAJOR_VERSION == (major) && GNOME_CANVAS_MINOR_VERSION > (minor)) || \
	 (GNOME_CANVAS_MAJOR_VERSION == (major) && GNOME_CANVAS_MINOR_VERSION == (minor) && GNOME_CANVAS_MICRO_VERSION >= (micro)))
